sketches

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2016 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BloomSketch

type BloomSketch struct {
	*datamodel.Info
	// contains filtered or unexported fields
}

BloomSketch is the toplevel Sketch to control the count-min-log implementation

func NewBloomSketch

func NewBloomSketch(info *datamodel.Info) (*BloomSketch, error)

NewBloomSketch ...

func (*BloomSketch) Add

func (d *BloomSketch) Add(values [][]byte) (bool, error)

Add ...

func (*BloomSketch) Get

func (d *BloomSketch) Get(data interface{}) (interface{}, error)

Get ...

type CMLSketch

type CMLSketch struct {
	*datamodel.Info
	// contains filtered or unexported fields
}

CMLSketch is the toplevel Sketch to control the count-min-log implementation

func NewCMLSketch

func NewCMLSketch(info *datamodel.Info) (*CMLSketch, error)

NewCMLSketch ...

func (*CMLSketch) Add

func (d *CMLSketch) Add(values [][]byte) (bool, error)

Add ...

func (*CMLSketch) Get

func (d *CMLSketch) Get(data interface{}) (interface{}, error)

Get ...

type HLLPPSketch

type HLLPPSketch struct {
	*datamodel.Info
	// contains filtered or unexported fields
}

HLLPPSketch is the toplevel sketch to control the HLL implementation

func NewHLLPPSketch

func NewHLLPPSketch(info *datamodel.Info) (*HLLPPSketch, error)

NewHLLPPSketch ...

func (*HLLPPSketch) Add

func (d *HLLPPSketch) Add(values [][]byte) (bool, error)

Add ...

func (*HLLPPSketch) Get

func (d *HLLPPSketch) Get(interface{}) (interface{}, error)

Get ...

type ResultElement

type ResultElement topk.Element

ResultElement ...

type SketchProxy

type SketchProxy struct {
	*datamodel.Info
	// contains filtered or unexported fields
}

SketchProxy ...

func CreateSketch

func CreateSketch(info *datamodel.Info) (*SketchProxy, error)

CreateSketch ...

func (*SketchProxy) Add

func (sp *SketchProxy) Add(values [][]byte) (bool, error)

Add ...

func (*SketchProxy) Get

func (sp *SketchProxy) Get(data interface{}) (interface{}, error)

Get ...

type TopKSketch

type TopKSketch struct {
	*datamodel.Info
	// contains filtered or unexported fields
}

TopKSketch is the toplevel sketch to control the HLL implementation

func NewTopKSketch

func NewTopKSketch(info *datamodel.Info) (*TopKSketch, error)

NewTopKSketch ...

func (*TopKSketch) Add

func (d *TopKSketch) Add(values [][]byte) (bool, error)

Add ...

func (*TopKSketch) Get

func (d *TopKSketch) Get(interface{}) (interface{}, error)

Get ...

Jump to