Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BloomSketch ¶
BloomSketch is the toplevel Sketch to control the count-min-log implementation
func NewBloomSketch ¶
func NewBloomSketch(info *datamodel.Info) (*BloomSketch, error)
NewBloomSketch ...
type HLLPPSketch ¶
HLLPPSketch is the toplevel sketch to control the HLL implementation
func NewHLLPPSketch ¶
func NewHLLPPSketch(info *datamodel.Info) (*HLLPPSketch, error)
NewHLLPPSketch ...
type SketchProxy ¶
SketchProxy ...
type TopKSketch ¶
TopKSketch is the toplevel sketch to control the HLL implementation
func NewTopKSketch ¶
func NewTopKSketch(info *datamodel.Info) (*TopKSketch, error)
NewTopKSketch ...
Click to show internal directories.
Click to hide internal directories.